@@ -197,6 +197,9 @@ MainView* interface_main_view_new(AppData *data)
       result->bShowFullscreenToolbar =
 	!gconf_client_get_bool(result->gc_client,
 			       MAEMO_VNCVIEWER_GCONF_FULLSCREEN_TOOLBAR, 0);
+//fremantle force FullscreenToolbar
+    result->bShowFullscreenToolbar = TRUE;
+
     result->bShowScrollbars =
       !gconf_client_get_bool(result->gc_client,
 			     MAEMO_VNCVIEWER_GCONF_SHOW_SCROLLBARS, 0);
@@ -1215,7 +1218,9 @@ static void callback_fullscreen_toggled(GtkCheckMenuItem *checkmenuitem, gpointe
   MainView *mainview = (MainView *) data;
 
   mainview->bShowFullscreenToolbar = !mainview->bShowFullscreenToolbar;
-  
+//fremantle force Fullscreen Toolbar
+  mainview->bShowFullscreenToolbar = TRUE;
+
   if (mainview->fullscreen)
   {
     if (mainview->bShowFullscreenToolbar)
